@@ -22,3 +22,7 @@ class IntegerPosition2D(Vector2[int]):
     def __isub__(self, other: Vector2[int]) -> 'IntegerPosition2D':
         super().__isub__(other)
         return self
+
+    def __neg__(self) -> 'IntegerPosition2D':
+        negation: Vector2[int] = super().__neg__()
+        return IntegerPosition2D(negation.x, negation.y)
